ApplicationContext

Struct ApplicationContext 

pub struct ApplicationContext { /* private fields */ }

Implementations

Source

impl ApplicationContext

pub fn empty(memory_options: MemoryOptions) -> Self

pub fn resources(&self) -> &Resources

pub fn memory(&self) -> &MemoryGovernor

pub fn register_memory_domain(&self, registration: DomainRegistration)

Registers an application-owned cache adapter and retains it for this context’s lifetime.

pub fn resource<T>(&self) -> Arc<T>
where T: Send + Sync + 'static,

pub fn try_resource<T>(&self) -> Option<Arc<T>>
where T: Send + Sync + 'static,

pub fn command<C>(&self) -> CommandHandle<C>
where C: Command,

pub async fn invoke<C>(&self, args: C::Args) -> Result<C::Output, C::Error>
where C: Command,

pub fn emit<E>(&self, event: E) -> usize
where E: Event,

pub fn subscribe<E>( &self, listener: impl Fn(E) + Send + Sync + 'static, ) -> EventSubscription
where E: Event,

pub fn subscribe_keyed<T>( &self, key: EventKey<T>, listener: impl Fn(T) + Send + Sync + 'static, ) -> EventSubscription
where T: Clone + Send + Sync + 'static,

pub fn set_executor(&self, executor: UiTaskSpawner)

pub fn spawn(&self, task: impl Future<Output = ()> + Send + 'static) -> bool

pub fn scope<F>(&self, future: F) -> impl Future<Output = F::Output>
where F: Future,

Runs a Future with this Application as the active context on every poll.

LGUI task APIs apply this automatically. Use scope when an application-owned Future is submitted to an external executor.

pub fn windows(&self) -> WindowManager