pub enum BlurEdgeMode {
Transparent,
Clamp,
}Variants
Transparent
Pixels sampled outside the affected region are treated as transparent.
Clamp
Pixels sampled outside the affected region clamp to the nearest edge pixel.