compositing_layer_damage

Function compositing_layer_damage 

pub fn compositing_layer_damage(
    previous: &[ScenePrimitive],
    next: &[ScenePrimitive],
    layer_bounds: UiRect,
) -> Vec<UiRect>
Computes the pixels that can change when a retained layer replaces one command list with another. Returned rectangles use the same local coordinate space as previous and next.