use_context

Function use_context 

pub fn use_context<T>() -> T
where T: Clone + 'static,
Reads a typed value from the nearest provider and subscribes the component currently being rendered to provider changes.