LayoutRuntime

Struct LayoutRuntime 

pub struct LayoutRuntime { /* private fields */ }

Implementations

Source

impl LayoutRuntime

pub fn new() -> Self

pub fn update(&mut self, tree: &mut HostTree) -> LayoutCommitMetrics

Resolves logical layout while retaining committed results per node. Paint-only changes do not execute layout; geometric changes execute only their nearest layout boundary subtree.

pub fn metrics(&self) -> LayoutCommitMetrics

pub fn clear(&mut self)